==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/es_MX.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imagen seleccionad es demaciado grande (max 1MB)",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field ..." : "Agregar campo",
    "No search result for {query}" : "No hay resultados en la busquede para {query}",
    "Postal code" : "Código postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "Last name" : "Apellido",
    "First name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "All contacts" : "Todos los contactos",
    "Not grouped" : "No agrupado",
    "New contact" : "Nuevo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "No contacts in file. Only VCard files are allowed." : "No hay contactos en el archivo. Solo se permiten archivos VCard.",
    "Nickname" : "Alias",
    "Detailed name" : "Detalle de nombre",
    "Notes" : "Notas",
    "Website" : "Sitio Web",
    "Federated Cloud ID" : "Mensajería instantanea",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Email" : "E-mail",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Social network" : "Red social",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/es_MX.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "Delete" : "Eliminar",
    "can edit" : "puede editar",
    "Address book name" : "Nombre de la libreta de direcciones",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imagen seleccionad es demaciado grande (max 1MB)",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field ..." : "Agregar campo",
    "No search result for {query}" : "No hay resultados en la busquede para {query}",
    "Post office box" : "Apartado de correos",
    "Postal code" : "Código postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "Last name" : "Apellido",
    "First name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "All contacts" : "Todos los contactos",
    "Not grouped" : "No agrupado",
    "New contact" : "Nuevo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "Contact could not be created." : "El contacto no se ha podido crear",
    "No contacts in file. Only VCard files are allowed." : "No hay contactos en el archivo. Solo se permiten archivos VCard.",
    "Nickname" : "Alias",
    "Detailed name" : "Detalle de nombre",
    "Notes" : "Notas",
    "Website" : "Sitio Web",
    "Federated Cloud ID" : "Mensajería instantanea",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de fallecimiento",
    "Email" : "E-mail",
    "Instant messaging" : "Mensajería instantanea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Social network" : "Red social",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");
